% Parameter der MD-Simulation
md_parameters;

% Zeit-Intervall der MD-Simulation
tspan = [0.,0.5]; % [nsec]

% Anfangs-Positionen [nm]
r0 = [ 0.  , 0.02, 0.34, 0.36,-0.02,-0.35,-0.31;   ...
       0.  , 0.39, 0.17,-0.21,-0.40,-0.16, 0.21;];
% Anfangs-Geschwindigkeiten [nm/nsec]
v0 = [ -30.,  50., -70.,  90.,  80., -40., -80.;   ...
       -20., -90., -60.,  40.,  90., 100., -60.;];

% Erstelle Anfangs-Loesungs-Vektor zur Eingabe in DGL Loeser
y0 = md_rv2y(r0,v0);

% Loese mit ode45 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Berechne mit ode45...');
tic; [t45,y45] = ode45(@md_rhs,tspan,y0); toc
% Totale Energie mit ode45
Etot45 = zeros(size(t45));
for j=1:length(t45)
  [rj,vj] = md_y2rv(y45(j,:));
  Etot45(j) = md_Etot(rj,vj);
end

% Loese mit Verlet-Algorithmus %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Berechne mit Verlet-Algorithmus...');
tic; [tsv,rsv,vsv] = ode_sv(@md_a,tspan,r0,v0,20000); toc
% Totale Energie mit Verlet-Algorithmus
Etotsv = zeros(size(tsv));
for j=1:length(tsv)
  rj = squeeze(rsv(j,:,:));
  vj = squeeze(vsv(j,:,:));
  Etotsv(j) = md_Etot(rj,vj);
end

% Plotte totale Energie (in kB Einheiten!)
clf;
hold on;
plot(t45,Etot45/kB);
plot(tsv,Etotsv/kB);
legend('ode45','Verlet-Algorithmus','Location','northwest');
title('Totale Energie der MD-Simulation');
xlabel('t [nsec]');
ylabel('Etot [kB]');
box on;
hold off;
% print('MD_Etot.eps','-depsc')

