clear all;
close all;

% Parameters
m1 = 10;
m2 = 15;

% RHS
g = @twobodyrhs;
f = @(t,y)(g(y,m1,m2));

% Initial conditions
r10 = [-5;0];
r20 = [5;0];
dotr10 = [0;0.1];
dotr20 = [0;-0.1];

t0 = 0;
T = 100;
h0 = 0.01;
y0 = [r10;r20;dotr10;dotr20];
absTol = 1.e-8;
relTol = 1.e-8;

% Aufruf des Loesers
[tadapt,yadapt] = RKF45(f,y0,t0,T,h0,absTol,relTol);

% plot step length
figure(10)
plot(diff(tadapt))

%%%%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%

% Set axes
factor = 1.1;
if (min(min(yadapt(3,:)),min(yadapt(1,:))) > 0)
  xmin = min(min(yadapt(3,:)),min(yadapt(1,:)))/factor;
else
  xmin = min(min(yadapt(3,:)),min(yadapt(1,:)))*factor;
end

if (max(max(yadapt(3,:)),max(yadapt(1,:))) > 0)
  xmax = max(max(yadapt(3,:)),max(yadapt(1,:)))*factor;
else
  xmax = max(max(yadapt(3,:)),max(yadapt(1,:)))/factor;
end

if (min(min(yadapt(2,:)),min(yadapt(4,:))) > 0)
  ymin = min(min(yadapt(2,:)),min(yadapt(4,:)))/factor;
else
  ymin = min(min(yadapt(2,:)),min(yadapt(4,:)))*factor;
end

if (max(max(yadapt(2,:)),max(yadapt(4,:))) > 0)
  ymax = max(max(yadapt(2,:)),max(yadapt(4,:)))*factor;
else
  ymax = max(max(yadapt(2,:)),max(yadapt(4,:)))/factor;
end

% Preallocate
nFrames = length(tadapt);
mov(1:nFrames) = struct('cdata',[], 'colormap',[]);

% Initialize figure
figure
set(gca, 'nextplot','replaceChildren','XLim',[xmin xmax],'YLim',[ymin ymax]);

% create movie

if (m1>m2)
  factor_plot = m1/m2;
else
  factor_plot = m2/m1;
end

for k=1:nFrames
  plot(yadapt(1,k),yadapt(2,k),'b.','MarkerSize',m1);
  hold on
  plot(yadapt(1,1:k),yadapt(2,1:k),'b--');
  hold on
  plot(yadapt(3,k),yadapt(4,k),'r.','MarkerSize',m2);
  hold on
  plot(yadapt(3,1:k),yadapt(4,1:k),'r--');
  hold off

  xlim([xmin,xmax]);
  ylim([ymin,ymax]);

  mov(k) = getframe(gcf);
end
close all;
