  function a = md_a(r)

% function a = md_a(r)
%
% Zweck: Berechne totale Beschleunigung in der MD-Simulation
%
% Parameters: r ... Positions-Vektor der Atome
%
% Returns: a ... Totale Beschleunigung der Atome
%
% Notes: 1) Parameter fuer die MD Simulation kommen von md_parameters.m.
%
%        2) Fuer den eingehenden Positions-Array r wird folgende Struktur
%           erwartet:
%
%             r(1  ,1) ... x  -Koordinate des Atoms 1
%             r(2  ,1) ... y  -Koordinate des Atoms 1
%             ...
%             r(dim,1) ... dim-Koordinate des Atoma 1
%             r(1  ,2) ... x  -Koordinate des Atoms 2
%             r(2  ,2) ... y  -Koordinate des Atoms 2
%             ...
%             r(dim,2) ... dim-Koordinate des Atoma 2
%
%           Usw.
%           Der ausgehende Beschleunigungs-Array a hat dieselbe Struktur.
%

% Parameter der MD-Simulation
  md_parameters;

% Berechne Kraefte von Atom alpha auf Atom beta
  f = zeros(dim,N,N);
  for alpha=1:N
    for beta=alpha+1:N
      rab  = r(:,alpha) - r(:,beta); % Vektor r_{alpha,beta}
      rabn = norm(rab,2);            % Laenge von r_{alpha,beta}
      % Kraft von Atom alpha auf Atom beta
      f(:,alpha,beta) = 48.*epsilon/sig^2                    ...
                      * ((sig/rabn)^14 - 0.5*(sig/rabn)^8) ...
                      * rab;
    end
  end
  % Berechne Kraft Atom beta auf Atom alpha mit Newton's 3. Gesetz
  % f_{alpha,beta} = - f_{beta,alpha}
  for idim=1:dim
    f(idim,:,:) = f(idim,:,:) - permute(f(idim,:,:),[1,3,2]);
  end

% Berechne totale Beschleunigung auf Atom alpha (Tot. Kraft / Masse)
  a = sum(f,3)/m;

