  function y = md_rv2y(r,v)

% function y = md_rv2y(r,v)
%
% Zweck: Sammle Positions- und Geschwindigkeits-Vektoren in
%        Loesungs-Vektor y
%
% Parameters: r ... Positions-Vektor der Atome
%             v ... Geschwindigkeits-Vektor der Atome
%
% Returns: y ... Loesungs-Vekotor
%
% Notes: Folgende Sortierungs-Konvention des Loesungs-Vektors wird
%        verwendet
%
%          y(0*dim+1  ) ... x  -Koordinate      des Atoms 1
%          y(0*dim+2  ) ... y  -Koordinate      des Atoms 1
%          ...
%          y(0*dim+dim) ... dim-Koordinate      des Atoms 1
%          y(1*dim+1  ) ... x  -Geschwindigkeit des Atoms 1
%          y(1*dim+2  ) ... y  -Geschwindigkeit des Atoms 1
%          ...
%          y(1*dim+dim) ... dim-Geschwindigkeit des Atoms 1
%          y(2*dim+1  ) ... x  -Koordinate      des Atoms 2
%          y(2*dim+2  ) ... y  -Koordinate      des Atoms 2
%          ...
%          y(2*dim+dim) ... dim-Koordinate      des Atoma 2
%          y(3*dim+1  ) ... x  -Geschwindigkeit des Atoms 2
%          y(3*dim+2  ) ... y  -Geschwindigkeit des Atoms 2
%          ...
%          y(3*dim+dim) ... dim-Geschwindigkeit des Atoms 2
%
%        Usw.
%

% Parameter der MD-Simulation
  md_parameters;

% Sammle Positions- und Geschwindigkeits-Vektoren in Loesungs-Vektor y
  y = zeros(dim*2*N,1);
  for alpha=1:N
    istart = 1 + (alpha - 1)*dim*2; % Start/End-Index des Positions-Vektors
    iend   = istart + dim - 1;      % von Atom alpha in Loesungs-Vekotor
    y(istart:iend) = r(:,alpha);
    istart = iend + 1;              % Start/End-Index des Geschwindigkeits-
    iend   = istart + dim - 1;      % Vektors von Atom alpha in Loesungs-Vekotor
    y(istart:iend) = v(:,alpha);
  end

