  function [t,r,v] = ode_sv(a,tspan,r0,v0,N)

% function [t,r,v] = ode_sv(a,tspan,r0,v0)
%
% Zweck: Integriere Mehr-Koerper-System mit Verlet-Algorithmus
%
% Parameters: a     ... Function-handle zu Beschleunigungs-Funktion
%             tspan ... Zeitintervall
%             r0    ... Anfangs-Positions-Vektor der Atome
%             v0    ... Anfangs-Geschwindigkeits-Vektor der Atome
%             N     ... Anzahl Zeitschritte
%
% Returns: t ... Zeit
%          r ... Positions-Vektor der Atome
%          v ... Geschwindigkeits-Vektor der Atome
%
% Notes: Keine.
%

% Berechne Schrittweite
  h = (tspan(2) - tspan(1))/N;

% Alloziere Speicher fuer Positions- und Geschwindigkeits-Loesungs-Vektoren
  t = zeros(N+1,1);
  r = zeros([N+1 size(r0)]);
  v = zeros([N+1 size(v0)]);

% Initialisiere Loesungs-Vektoren
  t(1) = tspan(1);
  r(1,:,:) = r0;
  v(1,:,:) = v0;

% Integriere mit Verlet-Algorithmus
  ajp = md_a(r0);
  for j=1:N
    t(j+1) = t(j) + h;
    aj = ajp;               % Beschleunigungen  a^{j}
    rj = squeeze(r(j,:,:)); % Positionen        r^{j}
    vj = squeeze(v(j,:,:)); % Geschwindigkeiten v^{j}
    % Integriere
    vjh = vj + 0.5*h*aj;   % v^{j+1/2}
    rjp = rj + h*vjh;      % r^{j+1}
    ajp = md_a(rjp);       % a^{j+1}
    vjp = vjh + 0.5*h*ajp; % v^{j+1}
    % Kopiere in Loesungs-Arrays
    r(j+1,:,:) = rjp;
    v(j+1,:,:) = vjp;
  end

